@@ -1,8 +1,15 @@
-from .editor import set_config
 from .config import Config
-
-from .editor import IconNormal, IconSkip, IconLoop, IconCompleteLoop, EditorLogo, EditorBanner
-from .editor import PresentationSectionType, get_config, set_config
+from .editor import (
+    EditorBanner,
+    EditorLogo,
+    IconCompleteLoop,
+    IconLoop,
+    IconNormal,
+    IconSkip,
+    PresentationSectionType,
+    get_config,
+    set_config,
+)
 
 set_config(Config)
 
